<?php
if (!defined('ABSPATH')) {
    exit;
}

class WC_Gateway_Paynoloji extends WC_Payment_Gateway
{
    private $api;

    public function __construct()
    {
        $this->id = 'paynoloji';
        $this->method_title = __('Paynoloji', PAYNOLOGI_PLUGIN_TEXTDOMAIN);
        $this->method_description = __('Paynoloji ile güvenli ödeme.', PAYNOLOGI_PLUGIN_TEXTDOMAIN);
        $this->has_fields = false;
        $this->supports = ['products'];

        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');

        $this->api = new Paynoloji_API(
            $this->get_option('app_id'),
            $this->get_option('app_secret')
        );

        add_action('woocommerce_update_options_payment_gateways_' . $this->id, [$this, 'process_admin_options']);
        add_action('woocommerce_receipt_' . $this->id, [$this, 'receipt_page']);
        add_action('woocommerce_api_paynoloji_callback', [$this, 'handle_callback']);
        add_action('wp_ajax_paynoloji_get_installments', [$this, 'ajax_get_installments']);
        add_action('wp_ajax_nopriv_paynoloji_get_installments', [$this, 'ajax_get_installments']);
    }

    public function init_form_fields()
    {
        $this->form_fields = [
            'enabled' => [
                'title' => __('Etkinleştir', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'type' => 'checkbox',
                'label' => __('Paynoloji ödeme yöntemini etkinleştir.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'default' => 'yes',
            ],
            'title' => [
                'title' => __('Başlık', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'type' => 'text',
                'description' => __('Ödeme sayfasında görüntülenecek başlık.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'default' => __('Paynoloji ile Öde', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
            ],
            'description' => [
                'title' => __('Açıklama', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'type' => 'textarea',
                'description' => __('Ödeme yöntemi için kısa bir açıklama.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'default' => __('Paynoloji ile güvenli bir şekilde ödeme yapabilirsiniz.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
            ],
            'app_id' => [
                'title' => __('API Key (App ID)', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'type' => 'text',
                'description' => __('Paynoloji panelinizde bulunan API Key bilgisini buraya girin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'default' => '',
                'desc_tip' => true,
            ],
            'app_secret' => [
                'title' => __('API Secret (App Secret)', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'type' => 'password',
                'description' => __('Paynoloji panelinizde bulunan API Secret bilgisini buraya girin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN),
                'default' => '',
                'desc_tip' => true,
            ],
        ];
    }

    public function process_payment($order_id)
    {
        $order = wc_get_order($order_id);

        return [
            'result' => 'success',
            'redirect' => $order->get_checkout_payment_url(true)
        ];
    }

    public function receipt_page($order_id)
    {
        $order = wc_get_order($order_id);

        if (!$order) {
            wc_add_notice(__('Geçersiz sipariş.', PAYNOLOGI_PLUGIN_TEXTDOMAIN), 'error');
            return;
        }

        if ($order->is_paid()) {
            wp_redirect($this->get_return_url($order));
            exit;
        }

        $form_data = $this->api->create_payment_session($order);

        if (isset($payment_data['error'])) {
            wc_add_notice($payment_data['error'], 'error');
            return;
        }
        $payment_url = PAYNOLOGI_API_URL . 'pay3D';

        // Form şablonunu yükle
        require_once PAYNOLOGI_PLUGIN_DIR . "templates/payment-form.php";
    }

    public function ajax_get_installments()
    {
        check_ajax_referer('paynoloji-installments', 'nonce');

        $bin = isset($_POST['bin']) ? sanitize_text_field($_POST['bin']) : '';
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;

        if (empty($bin) || $amount <= 0) {
            wp_send_json_error(__('Geçersiz parametreler.', PAYNOLOGI_PLUGIN_TEXTDOMAIN));
            return;
        }

        $installments = $this->api->get_installments($bin, $amount);

        if (isset($installments['error'])) {
            wp_send_json_error($installments['error']);
            return;
        }

        // Validate installment count
        if (!isset($installments['installments']) || !is_array($installments['installments'])) {
            wp_send_json_error(__('Geçersiz taksit bilgisi.', PAYNOLOGI_PLUGIN_TEXTDOMAIN));
            return;
        }

        // Ensure the installment count is within an acceptable range (e.g., 1 to 12)
        $filtered_installments = array_filter($installments['installments'], function ($installment) {
            return $installment['count'] >= 1 && $installment['count'] <= 12;
        });

        if (empty($filtered_installments)) {
            wp_send_json_error(__('Uygun taksit seçeneği bulunamadı.', PAYNOLOGI_PLUGIN_TEXTDOMAIN));
            return;
        }

        $installments['installments'] = array_values($filtered_installments);

        wp_send_json_success($installments);
    }

    public function handle_callback()
    {
        $raw_data = file_get_contents('php://input');
        $data = json_decode($raw_data, true);

        if (!isset($data['order_id']) || !isset($data['status'])) {
            error_log('Paynoloji: Geçersiz geri çağırma verisi - ' . $raw_data);
            status_header(400);
            exit;
        }

        $order = wc_get_order(intval($data['order_id']));
        if (!$order) {
            error_log('Paynoloji: Geçersiz sipariş ID - ' . $data['order_id']);
            status_header(400);
            exit;
        }

        if ($data['status'] === 'success') {
            $order->payment_complete();
            $order->add_order_note(__('Paynoloji üzerinden ödeme başarılı.', PAYNOLOGI_PLUGIN_TEXTDOMAIN));
        } else {
            $order->update_status('failed', __('Paynoloji üzerinden ödeme başarısız.', PAYNOLOGI_PLUGIN_TEXTDOMAIN));
        }

        status_header(200);
        exit;
    }
}
